@@ -1,7 +1,9 @@
 from avatar_utils.db.mixins.crud import CRUDMixin
+from avatar_utils.db.mixins.json_cast import JsonCastMixin
 from avatar_utils.db.mixins.time_cast import TimeCastMixin
 
 __all__ = [
     'CRUDMixin',
     'TimeCastMixin',
+    'JsonCastMixin',
 ]
